==> ejc-outcontract-impl-3.0.0-20250929.062545-320-sources.jar: com/ejianc/foundation/calibration/bean/CalibrationSupplierEntity.java <==
package com.ejianc.foundation.calibration.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 招标(定标)信息-供应商
 * 
 * @author generator
 * 
 */
 @TableName("ejc_calibration_supplier")
public class CalibrationSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="calibration_id")
    private Long calibrationId; // 招标(定标)信息ID
    @TableField(value="supplier_sys_no")
    private String supplierSysNo; // 项目编号
    @TableField(value="supplier_main_sys_no")
    private String supplierMainSysNo; // 项目编号
    @TableField(value="supplier_name")
    private String supplierName; // 项目名称
    @TableField(value="supplier_id")
    private Long supplierId; // 项目ID（平台）

    public Long getCalibrationId() {
        return calibrationId;
    }

    public void setCalibrationId(Long calibrationId) {
        this.calibrationId = calibrationId;
    }
    public String getSupplierSysNo() {
        return supplierSysNo;
    }

    public void setSupplierSysNo(String supplierSysNo) {
        this.supplierSysNo = supplierSysNo;
    }
    public String getSupplierMainSysNo() {
        return supplierMainSysNo;
    }

    public void setSupplierMainSysNo(String supplierMainSysNo) {
        this.supplierMainSysNo = supplierMainSysNo;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20251022.020553-368-sources.jar: com/ejianc/foundation/calibration/bean/CalibrationSupplierEntity.java <==
package com.ejianc.foundation.calibration.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 招标(定标)信息-供应商
 * 
 * @author generator
 * 
 */
 @TableName("ejc_calibration_supplier")
public class CalibrationSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="calibration_id")
    private Long calibrationId; // 招标(定标)信息ID
    @TableField(value="supplier_status")
    private String supplierStatus; // 供应商状态
    @TableField(value="supplier_sys_no")
    private String supplierSysNo; // 供应商编号
    @TableField(value="supplier_main_sys_no")
    private String supplierMainSysNo; // 供应商编号
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商ID（平台）

    public Long getCalibrationId() {
        return calibrationId;
    }

    public void setCalibrationId(Long calibrationId) {
        this.calibrationId = calibrationId;
    }
    public String getSupplierSysNo() {
        return supplierSysNo;
    }

    public void setSupplierSysNo(String supplierSysNo) {
        this.supplierSysNo = supplierSysNo;
    }
    public String getSupplierMainSysNo() {
        return supplierMainSysNo;
    }

    public void setSupplierMainSysNo(String supplierMainSysNo) {
        this.supplierMainSysNo = supplierMainSysNo;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(String supplierStatus) {
        this.supplierStatus = supplierStatus;
    }
}
